#
# spec file for package mingw32-headers
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mingw32-headers
Version:        12.0.0
Release:        1.1
Summary:        MinGW-w64 headers for Win32 and Win64
License:        SUSE-Public-Domain
Group:          Development/Libraries/C and C++
URL:            http://mingw-w64.sf.net/
Source:         http://downloads.sf.net/mingw-w64/mingw-w64-v%version.tar.bz2
Source1000:     %name-rpmlintrc
Patch0:         mingw-w64-v9.0.0-strnlen_s.patch
Patch1:         mingw-w64-v11.0.1-fix-undefined-interface-type.patch
BuildRequires:  mingw32-filesystem
BuildRequires:  xz
#!BuildIgnore:	post-build-checks
Requires:       mingw32-unistd-pthread-devel
BuildArch:      noarch

%description
MinGW-w64 delivers runtime, headers and libs for developing both 64
bit (x64) and 32 bit (x86) windows applications using GCC and other
free software compilers.

This subpackage contains the header files.

%package dummy-pthread
Summary:        Stub pthread header files for MinGW
Group:          Development/Libraries/C and C++
Provides:       mingw32-unistd-pthread-devel

%description dummy-pthread
This subpackage contains stub pthread header files that are empty
and only exist to satisfy dependencies in MinGW's unistd.h until
an actual pthread implementation (like winpthreads) is installed.

%prep
%autosetup -n mingw-w64-v%version/mingw-w64-headers -p2

%build
%_mingw32_configure --enable-sdk=all --with-default-msvcrt=msvcrt
%make_build

%install
%make_install

%files
%_mingw32_includedir/
%exclude %_mingw32_includedir/pthread_*.h

%files dummy-pthread
%dir %_mingw32_includedir
%_mingw32_includedir/pthread_*.h

%changelog
* Mon Oct  7 2024 Jan Engelhardt <jengelh@inai.de>
- Delete --enable-secure-api, this is gone since mingw 7.
* Sun Oct  6 2024 Ralf Habacker <ralf.habacker@freenet.de>
- Fixes build errors in other packages due to undefined
  references of "_imp____sys_nerr" and others caused by
  this package not being synchronized with the mingw32-runtime
  package (--with-default-msvcrt=msvcrt must be used).
* Wed Aug 28 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 12
  * C++ overloads for _strdate_s and _strtime_s, _makepath_s,
    wcsncat_s.
  * Updated wine header imports.
  * Many other new win32 APIs.
  * UCRT configurations now primarily use (faster) math functions
    from UCRT, rather than libmingwex.
* Sat Nov 11 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Added patch:
  * mingw-w64-v11.0.1-fix-undefined-interface-type.patch
    + fix build issue with gcc13: type 'interface' is undefined
* Fri Nov  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 11.0.1
  * New Hyper-V APIs
  * Updates to DX12 headers and much more from Wine
  * Many other new Win32 APIs
* Mon Jun 27 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 10
  * New msvcrt10, 20, 40, 70 and 71 import libraries.
  * Updated wine imports
  * Fix intrin.h compatibility with GCC-11
* Thu Jul  8 2021 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * mingw-w64-v9.0.0-strnlen_s.patch
    + work around the "multiple definition of `strnlen_s'" error
    + the function still accessible by defining _NEEDS_STRNLEN_S
    before inclusion of the header
* Fri Jul  2 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 9.0.0
  * Various new and updated API headers
  * at_quick_exit implementation
  * dism API
* Thu Dec  3 2020 Tobias Klausmann <tobias.klausmann@freenet.de>
- Update to new upstream release 8.0.0
  * New Hyper-V headers and libraries by Biswapriyo Nath
  * Many headers updated from Wine by Jacek Caban.
  * ARM math improvements by Martin Storsjö
  * floating point fixes by Liu Hao
  * many *printf compatibility fixes by Liu Hao and Martin Storsjö
  * massive Windows App Store API updates by Steve Lhomme
  * winstorecompat library updates by Martin Storsjö
  * __USE_MINGW_ANSI_STDIO now automatically enabled in C99 and C11 mode when
    not using UCRT by Pali Rohár
  * wdm and ddk updates by Zebediah Figura
  * UCRT for Windows Store Apps (-lucrtapp) by Martin Storsjö
  * Audioclient and ActivateAudioInterfaceAsync API updates by Liu Hao
  * DirectX SDKs are now always installed
* Sat Nov 23 2019 Ismail Dönmez <idonmez@suse.com>
- Update to new upstream release 7.0.0
  * _FORTIFY_SOURCE support thanks to Christian Franke.
  * Lots of math fixes from Martin Storsjö.
  * Many headers updated from Wine by Jacek Caban.
  * UCRT support by Martin Storsjö.
* Wed Oct 17 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 6.0.0
  * C++ __cxa_atexit
  * Massive additions to support UCRT
  * Sync COM interface headers with Wine development
  * WinRT additions
  * ARM32 and ARM64 additions
  * CRT library api-ms-win-core additions
  * CRT library def file reorganization
- Removed popcnt.patch, 0001-Add-missing-D3D_CS_-variables.patch
  (no longer needed; included upstream)
* Wed Nov 22 2017 idonmez@suse.com
- Update to version 5.0.3
* Thu Apr 20 2017 idonmez@suse.com
- Add popcnt.patch
* Tue Mar 28 2017 idonmez@suse.com
- Update to version 5.0.2
  * RegSetKeyValueW now has proper wide arguments.
  * Fix pdh.h function calls to have proper stdcall decorators.
* Sat Jan 14 2017 idonmez@suse.com
- Update to version 5.0.1
* Wed Mar 23 2016 jengelh@inai.de
- Update to new upstream release 5.0~rc1
  * Basic ARM support
  * gcc-5 support
* Fri Sep  4 2015 idonmez@suse.com
- Update to version 4.0.4
  * Fixes to tchar.h
- Remove order.diff, upstream
* Tue Apr 21 2015 jengelh@inai.de
- Update to new upstream release 4.0.2
  * Fix PdhValidatePathExW declaration.
  * Fix WAVE_FORMAT_POLYCOM_G729_A typo in mmreg.h.
  * Fix missing newlines separating define macros in commctrl.h.
* Thu Mar 26 2015 jengelh@inai.de
- Add order.diff to fix SHGetFolderPathW compile errors in code
  using shlobj.h.
* Wed Mar 25 2015 jengelh@inai.de
- Update to mingw-w64-4.0.1
  * 32-bit ARM thumb software math
  * Improved DirectX 11, OpenGL 4.5/GLES 3.1 support
  * added POSIX.1-2008 ftw.h
  * more secure functions: qsort_s, gmtime64_s, time_s.h, ...
  * added to stat.h: S_IRGRP, S_IRWXG, ...
  * added to unistd.h: SHUT_*
